package LibStorage::ContVolInfo;
BEGIN {
    %TYPEINFO = (
        ALL_METHODS => 0,
        new => ["function", "any", "string"],
        swig_ctype_get => ["function", "integer", "any"],
        swig_ctype_set => ["function", "void", "any", "integer"],
        swig_cname_get => ["function", "string", "any"],
        swig_cname_set => ["function", "void", "any", "string"],
        swig_cdevice_get => ["function", "string", "any"],
        swig_cdevice_set => ["function", "void", "any", "string"],
        swig_vname_get => ["function", "string", "any"],
        swig_vname_set => ["function", "void", "any", "string"],
        swig_vdevice_get => ["function", "string", "any"],
        swig_vdevice_set => ["function", "void", "any", "string"],
        swig_num_get => ["function", "integer", "any"],
        swig_num_set => ["function", "void", "any", "integer"],
    );
}

1;
